"use strict";



var _chunkPHMY7N4Dcjs = require('../chunk-PHMY7N4D.cjs');


var _chunkL7FR4LKNcjs = require('../chunk-L7FR4LKN.cjs');
require('../chunk-N5KTMDVO.cjs');
require('../chunk-BOHPEXDM.cjs');
require('../chunk-6T6PI6XG.cjs');
require('../chunk-5BF2LEAU.cjs');
require('../chunk-4NW2WSOT.cjs');
require('../chunk-SUHO4WFP.cjs');
require('../chunk-S6C65KDQ.cjs');
require('../chunk-UKD65B23.cjs');
require('../chunk-PEU5ZQVB.cjs');
require('../chunk-J42M6DF3.cjs');
require('../chunk-ZYPCVNSG.cjs');
require('../chunk-N43PGEL6.cjs');
require('../chunk-W3WUDQIC.cjs');
require('../chunk-YY4AHBBL.cjs');



var _chunkIMCDDJAJcjs = require('../chunk-IMCDDJAJ.cjs');

// src/common/dispose-utils.spec.ts
var _vitest = require('vitest');
describe("useTimeout", () => {
  it("should call the provided function after the specified timeout", () => {
    _vitest.vi.useFakeTimers();
    const mockFn = _vitest.vi.fn();
    const timeout = 1e3;
    _chunkPHMY7N4Dcjs.useTimeout.call(void 0, mockFn, timeout);
    expect(mockFn).not.toBeCalled();
    _vitest.vi.advanceTimersByTime(timeout);
    expect(mockFn).toBeCalled();
  });
  it("should cancel the timeout when the disposer function is called", () => {
    _vitest.vi.useFakeTimers();
    const mockFn = _vitest.vi.fn();
    const timeout = 1e3;
    const disposer = _chunkPHMY7N4Dcjs.useTimeout.call(void 0, mockFn, timeout);
    expect(mockFn).not.toBeCalled();
    disposer();
    _vitest.vi.advanceTimersByTime(timeout);
    expect(mockFn).not.toBeCalled();
  });
  it('should add event listener using "on" method if available', () => {
    const emitter = {
      on: _vitest.vi.fn(),
      off: _vitest.vi.fn()
    };
    const eventName = "click";
    const fn = _vitest.vi.fn();
    const args = [1, 2, 3];
    const disposer = _chunkPHMY7N4Dcjs.useEventListener.call(void 0, emitter, eventName, fn, ...args);
    expect(emitter.on).toBeCalledWith(eventName, fn, ...args);
    expect(emitter.off).not.toBeCalled();
    disposer();
    expect(emitter.off).toBeCalledWith(eventName, fn, ...args);
  });
  it('should add event listener using "on" method if available using using', () => {
    const emitter = {
      on: _vitest.vi.fn(),
      off: _vitest.vi.fn()
    };
    const eventName = "click";
    const fn = _vitest.vi.fn();
    const args = [1, 2, 3];
    _chunkL7FR4LKNcjs.polyfillUsing.call(void 0, );
    function helper() {
      var _stack = [];
      try {
        const _ = _chunkIMCDDJAJcjs.__using.call(void 0, _stack, _chunkPHMY7N4Dcjs.useEventListener.call(void 0, emitter, eventName, fn, ...args));
        expect(emitter.on).toBeCalledWith(eventName, fn, ...args);
        expect(emitter.off).not.toBeCalled();
      } catch (_2) {
        var _error = _2, _hasError = true;
      } finally {
        _chunkIMCDDJAJcjs.__callDispose.call(void 0, _stack, _error, _hasError);
      }
    }
    helper();
    expect(emitter.off).toBeCalledWith(eventName, fn, ...args);
  });
  it('should add event listener using "addEventListener" method if "on" method is not available', () => {
    const emitter = {
      addEventListener: _vitest.vi.fn(),
      removeEventListener: _vitest.vi.fn()
    };
    const eventName = "click";
    const fn = _vitest.vi.fn();
    const args = [1, 2, 3];
    const disposer = _chunkPHMY7N4Dcjs.useEventListener.call(void 0, emitter, eventName, fn, ...args);
    expect(emitter.addEventListener).toBeCalledWith(eventName, fn, ...args);
    expect(emitter.removeEventListener).not.toBeCalled();
    disposer();
    expect(emitter.removeEventListener).toBeCalledWith(eventName, fn, ...args);
  });
  it("should return an empty disposer function if emitter is null", () => {
    const emitter = null;
    const eventName = "click";
    const fn = _vitest.vi.fn();
    const args = [1, 2, 3];
    const disposer = _chunkPHMY7N4Dcjs.useEventListener.call(void 0, emitter, eventName, fn, ...args);
    expect(disposer).toEqual(expect.any(Function));
    disposer();
  });
  it("should add timeout disposer to the dispose object", () => {
    _vitest.vi.useFakeTimers();
    const mockFn = _vitest.vi.fn();
    const timeout = 1e3;
    const dispose = _chunkPHMY7N4Dcjs.useDisposeWithUtils.call(void 0, );
    dispose.timeout(mockFn, timeout);
    expect(mockFn).not.toBeCalled();
    _vitest.vi.advanceTimersByTime(timeout);
    expect(mockFn).toBeCalled();
  });
  it("should add interval disposer to the dispose object", () => {
    _vitest.vi.useFakeTimers();
    const mockFn = _vitest.vi.fn();
    const interval = 1e3;
    const dispose = _chunkPHMY7N4Dcjs.useDisposeWithUtils.call(void 0, );
    dispose.interval(mockFn, interval);
    expect(mockFn).not.toBeCalled();
    _vitest.vi.advanceTimersByTime(interval);
    expect(mockFn).toBeCalled();
  });
  it('should add event listener disposer to the dispose object using "on" method', async () => {
    const emitter = {
      on: _vitest.vi.fn(),
      off: _vitest.vi.fn()
    };
    const eventName = "click";
    const fn = _vitest.vi.fn();
    const args = [1, 2, 3];
    const dispose = _chunkPHMY7N4Dcjs.useDisposeWithUtils.call(void 0, );
    dispose.on(emitter, eventName, fn, ...args);
    expect(emitter.on).toBeCalledWith(eventName, fn, ...args);
    expect(emitter.off).not.toBeCalled();
    await dispose.dispose();
    expect(emitter.off).toBeCalledWith(eventName, fn, ...args);
  });
  it('should add event listener disposer to the dispose object using "addEventListener" method', async () => {
    const emitter = {
      addEventListener: _vitest.vi.fn(),
      removeEventListener: _vitest.vi.fn()
    };
    const eventName = "click";
    const fn = _vitest.vi.fn();
    const args = [1, 2, 3];
    const dispose = _chunkPHMY7N4Dcjs.useDisposeWithUtils.call(void 0, );
    dispose.on(emitter, eventName, fn, ...args);
    expect(emitter.addEventListener).toBeCalledWith(eventName, fn, ...args);
    expect(emitter.removeEventListener).not.toBeCalled();
    await dispose.dispose();
    expect(emitter.removeEventListener).toBeCalledWith(eventName, fn, ...args);
  });
  it("should return an empty disposer function if emitter is null 2", () => {
    const emitter = null;
    const eventName = "click";
    const fn = _vitest.vi.fn();
    const args = [1, 2, 3];
    const dispose = _chunkPHMY7N4Dcjs.useDisposeWithUtils.call(void 0, );
    const disposer = dispose.on(emitter, eventName, fn, ...args);
    expect(disposer).toEqual(expect.any(Function));
    disposer();
  });
});
//# sourceMappingURL=dispose-utils.spec.cjs.map