import {
  boolean,
  float,
  int,
  literal,
  number,
  object,
  string,
  stringLiterals,
  tuple,
  union
} from "../../chunk-QY5DHPIN.js";
import "../../chunk-4KRISKYA.js";
import "../../chunk-ZG6VDVZD.js";
import "../../chunk-PLBFBDKH.js";
import "../../chunk-ZDZ4EQHN.js";
import "../../chunk-PZP2B3FC.js";
import "../../chunk-2H4XRKWS.js";
import "../../chunk-NSJKG6AJ.js";
import "../../chunk-PRHMI3L4.js";
import "../../chunk-XBBCTS7U.js";
import "../../chunk-2OUSR2BE.js";
import "../../chunk-IJSLJFYU.js";
import "../../chunk-2HWPZ6ZE.js";
import "../../chunk-73CVRDI7.js";
import "../../chunk-OP4KFE7G.js";
import "../../chunk-DGP32WEQ.js";
import "../../chunk-EDNCPFSF.js";
import "../../chunk-OKCAAGML.js";
import "../../chunk-GBF7F7TQ.js";
import "../../chunk-D3JF6HTL.js";
import "../../chunk-V4QYOVRJ.js";
import "../../chunk-DVBRAJ3X.js";
import "../../chunk-SZJLXMYP.js";
import "../../chunk-GKKLBSFA.js";
import "../../chunk-RNL46FQ3.js";
import "../../chunk-MWUFUBY5.js";
import "../../chunk-NKO3DYD7.js";
import "../../chunk-KKN5DQUJ.js";
import "../../chunk-X56GIAWQ.js";
import "../../chunk-XOAKJFNZ.js";
import "../../chunk-WJUQ3VXF.js";
import "../../chunk-FL5CT6MC.js";
import "../../chunk-F7LYIQZT.js";
import "../../chunk-SQYI5DA5.js";
import "../../chunk-BORRWM4T.js";
import "../../chunk-L324TYGN.js";
import "../../chunk-K7Z2KDW3.js";
import "../../chunk-GY34N3KU.js";
import "../../chunk-QUKKMPRF.js";
import "../../chunk-7U5RS62D.js";
import "../../chunk-WLMUUSZB.js";
import "../../chunk-ZQHU4QFM.js";
import "../../chunk-I2HNS75U.js";
import "../../chunk-MTV32UFZ.js";
import "../../chunk-PN34O4SN.js";
import "../../chunk-MIZOLME5.js";
import "../../chunk-JAGWOLOG.js";
import "../../chunk-YX6CL4KH.js";
import "../../chunk-CFICINSP.js";
import "../../chunk-MSASB4XB.js";
import {
  cloneJsonObject
} from "../../chunk-UOAPXGA4.js";
import "../../chunk-EAYWSLQT.js";
import "../../chunk-I7BWSAN6.js";

// src/common/schema/schema.spec.ts
describe("schema", () => {
  it("create schema", async () => {
    const lit = stringLiterals(["active", "trialing", "past_due", "paused", "deleted"]);
    expectTypeOf().toMatchTypeOf();
    const tup = tuple([number(), string(), boolean()]);
    expectTypeOf().toMatchTypeOf();
    const s1 = string().optional();
    expectTypeOf().toMatchTypeOf();
    const schema = object({
      id: string().default("123"),
      // default(() => '123'),
      name: string(),
      age: int().optional(),
      active: boolean(),
      // status: stringLiterals(['active', 'trialing', 'past_due', 'paused', 'deleted']),
      // status: string<Status>(),
      obj: object({
        test: float()
      }).optional(),
      lit
    });
    const sample = {
      name: "Hello",
      age: 42,
      active: true,
      lit: "past_due"
    };
    expect(cloneJsonObject(schema)).toMatchInlineSnapshot(`
      Object {
        "_object": Object {
          "active": Object {
            "type": "boolean",
          },
          "age": Object {
            "_optional": true,
            "type": "int",
          },
          "id": Object {
            "_default": "123",
            "type": "string",
          },
          "lit": Object {
            "type": "string",
          },
          "name": Object {
            "type": "string",
          },
          "obj": Object {
            "_object": Object {
              "test": Object {
                "type": "number",
              },
            },
            "_optional": true,
            "type": "object",
          },
        },
        "type": "object",
      }
    `);
    expect(schema.parse(sample)).toMatchInlineSnapshot(`
      Object {
        "active": true,
        "age": 42,
        "id": "123",
        "lit": "past_due",
        "name": "Hello",
      }
    `);
    expect(schema.map(sample, (v, s) => {
      if (s.type === "boolean") {
        return v ? "on" : "off";
      }
    })).toMatchInlineSnapshot(`
      Object {
        "active": "on",
        "age": 42,
        "lit": "past_due",
        "name": "Hello",
        "obj": Object {},
      }
    `);
    expect(schema.map(sample, function(v) {
      if (this.type === "boolean") {
        return v ? "yes" : "no";
      }
    })).toMatchInlineSnapshot(`
      Object {
        "active": "yes",
        "age": 42,
        "lit": "past_due",
        "name": "Hello",
        "obj": Object {},
      }
    `);
  });
  it("union", async () => {
    const literals = [
      literal("one"),
      literal("two"),
      literal("three")
    ];
    const schema = object({
      id: string().default(() => "123").props({
        // someProp: 'someValue',
      }),
      literal: literal("demo"),
      name: union(literals)
    });
    const sample = {
      literal: "demo",
      name: "two"
    };
    expect(cloneJsonObject(schema)).toMatchInlineSnapshot(`
      Object {
        "_object": Object {
          "id": Object {
            "_props": Object {},
            "type": "string",
          },
          "literal": Object {
            "type": "string",
          },
          "name": Object {
            "type": "string",
          },
        },
        "type": "object",
      }
    `);
    expect(schema.parse(sample)).toMatchInlineSnapshot(`
      Object {
        "id": "123",
        "literal": "demo",
        "name": "two",
      }
    `);
  });
  it("union with object", async () => {
    const obj = union([
      object({ subscription: literal(true), subscriptionId: string() }),
      object({ subscription: literal(false), licenseId: string() })
    ]);
    expectTypeOf().toMatchTypeOf();
  });
});
//# sourceMappingURL=schema.spec.js.map